@@ -71,16 +71,16 @@ class City:
         city_map = reader.Map(self.center, self.edges, rgb_im.size[0], rgb_im.size[1])
         city_map.attach_nodes(self.boundaries)
         reader.write_coordinates(self.save_dir, city_map.nodes)
-        with open('cityarray.js', 'w') as f:
-            f.write('var COORDINATES = [\n')
-            for node_collection in self.boundaries:
-                f.write('[\n')
-                for node in node_collection:
-                    f.write('new google.maps.LatLng({}, {}),\n'.format(node.lat, node.lng))
-                f.write('],\n')    
-            f.write('];\n')
-            f.write('\n')
-            f.write('var INFO = "{}, {}";'.format(self.center, self.zoom))
+        # with open('cityarray.js', 'w') as f:
+        #     f.write('var COORDINATES = [\n')
+        #     for node_collection in self.boundaries:
+        #         f.write('[\n')
+        #         for node in node_collection:
+        #             f.write('new google.maps.LatLng({}, {}),\n'.format(node.lat, node.lng))
+        #         f.write('],\n')    
+        #     f.write('];\n')
+        #     f.write('\n')
+        #     f.write('var INFO = "{}, {}";'.format(self.center, self.zoom))
 
     def as_dict(self):
         boundaries = []
